@@ -1,9 +1,9 @@
-from argparse import ArgumentParser
-from dodo_commands.framework import Dodo
-from dodo_commands.framework.config import ConfigIO
-from dodo_commands.framework import CommandError
 import os
 import sys
+from argparse import ArgumentParser
+
+from dodo_commands import CommandError, Dodo
+from dodo_commands.framework.config_io import ConfigIO
 
 
 def _args():
@@ -53,31 +53,40 @@ def _layer_value(layers, layer):
     return None
 
 
+def _layers(config, filter_abs_paths=False):
+    layers = config.get('LAYERS', [])
+    if filter_abs_paths:
+        layers = [
+            x for x in layers
+            if not os.path.exists(os.path.expanduser(os.path.dirname(x)))
+        ]
+    return layers
+
+
 if Dodo.is_main(__name__, safe=False):
     args = _args()
-    config = ConfigIO().load(load_layers=False)
-    layers = config.get('ROOT', {}).get('layers', [])
+    config = ConfigIO().load()
 
     if args.layer == False:  # noqa
-        for layer in layers:
+        filtered_layers = _layers(config, filter_abs_paths=True)
+        for layer in filtered_layers:
             name = _layer_name(layer)
             if name:
-                value = _layer_value(layers, name)
+                value = _layer_value(filtered_layers, name)
                 if value:
-                    print(name + ': ' + _layer_value(layers, name))
+                    print(name + ': ' + _layer_value(filtered_layers, name))
         sys.exit(0)
 
+    layers = _layers(config)
     if args.value == False:  # noqa
         print(_layer_value(layers, args.layer))
         sys.exit(0)
 
-    layer_file = os.path.join(
-        Dodo.get_config("/ROOT/res_dir"),
-        "%s.%s.yaml" % (args.layer, args.value))
+    layer_file = os.path.join(Dodo.get_config("/ROOT/config_dir"),
+                              "%s.%s.yaml" % (args.layer, args.value))
 
     if not args.force and not os.path.exists(layer_file):
         raise CommandError("Layer file %s does not exist" % layer_file)
 
-    newlayers = _update_list_of_layers(layers, args.layer, args.value)
-    config['ROOT']['layers'] = newlayers
+    config['LAYERS'] = _update_list_of_layers(layers, args.layer, args.value)
     ConfigIO().save(config)
